@@ -1,6 +1,6 @@
 package Business::ISBN;
-# $Revision: 1.60 $
-# $Id: ISBN.pm,v 1.60 2001/04/01 21:09:04 brian Exp $
+# $Revision: 1.64 $
+# $Id: ISBN.pm,v 1.64 2001/09/05 05:36:57 comdog Exp $
 
 use strict;
 use subs qw( _common_format _checksum is_valid_checksum
@@ -15,6 +15,8 @@ use vars qw( $VERSION @ISA @EXPORT_OK $debug %country_data
 
 use Exporter;
 
+use Business::ISBN::Data;
+
 my $debug = 0;
 
 @ISA       = qw(Exporter);
@@ -22,7 +24,7 @@ my $debug = 0;
 	INVALID_COUNTRY_CODE INVALID_PUBLISHER_CODE
 	BAD_CHECKSUM GOOD_ISBN BAD_ISBN);
 
-($VERSION)   = q$Revision: 1.60 $ =~ m/(\d+\.\d+)\s*$/;
+($VERSION)   = q$Revision: 1.64 $ =~ m/(\d+\.\d+)\s*$/;
 
 sub INVALID_COUNTRY_CODE   { -2 };
 sub INVALID_PUBLISHER_CODE { -3 };
@@ -327,118 +329,6 @@ sub _common_format
 	return;
 	}
 
-BEGIN { 
-%country_data = (
-965 => [ 'ISRAEL', ['00',19,200,599,7000,7999,90000,99999]],
-982 => [ 'SOUTH PACIFIC', ['0','0']],
-9989 => [ 'MACEDONIA', ['0',2,30,59,600,969,9700,9999]],
-9983 => [ 'GAMBIA', [80,94,950,989,9900,9999]],
-87 => [ 'DENMARK', ['00',29,400,649,7000,7999,85000,94999,970000,999999]],
-99903 => [ 'MAURITIUS', ['0',1,20,89,900,999]],
-953 => [ 'CROATIA', ['0','0',10,14,150,599,6000,9599,96000,99999]],
-975 => [ 'TURKEY', ['00',29,300,599,6000,9199,92000,97999]],
-957 => [ 'TAIWAN', ['00',43,440,849,8500,9699,97000,99999]],
-85 => [ 'BRAZIL', ['00',19,200,699,7000,8499,85000,89999,900000,999999]],
-5 => [ 'RUSSIAN FEDERATION', ['00',19,200,699,7000,8499,85000,89999,900000,949999,9500000,9999999]],
-971 => [ 'PHILIPPINES', ['00',49,500,849,8500,9099,91000,99999]],
-970 => [ 'MEXICO', ['00',59,600,899,9000,9099,91000,99999]],
-968 => [ 'MEXICO', [10,39,400,499,800,899,6000,7999]],
-99917 => [ 'BRUNEI', ['0','0']],
-960 => [ 'GREECE', ['00',19,200,699,7000,8499,85000,99999]],
-966 => [ 'UKRAINE', ['00',29,500,599,7000,7999,90000,99999]],
-9979 => [ 'ICELAND', ['0',4,50,79,800,899,9000,9999]],
-99916 => [ 'NAMIBIA', ['0',2,30,69,700,999]],
-952 => [ 'FINLAND', ['00',19,89,94,200,499,5000,8899,9500,9899,99000,99999]],
-951 => [ 'FINLAND', ['0',1,20,54,550,899,8900,9499,95000,99999]],
-9974 => [ 'URAGUAY', ['0',2,30,54,550,749,7500,9999]],
-978 => [ 'NIGERIA', ['000',199,2000,2999,30000,99999]],
-'0' => [ 'UK/US ENGLISH', ['00',19,200,699,7000,8499,85000,89999,900000,949999,9500000,9999999]],
-1 => [ 'UK/US ENGLISH', [55000,86979,869800,998999,9999900,9999999]],
-99914 => [ 'SURINAME', ['0',4,50,89,900,949]],
-956 => [ 'CHILE', ['00',19,200,699,7000,9999]],
-91 => [ 'SWEDEN', ['0',1,20,49,500,649,7000,7999,85000,94999,970000,999999]],
-984 => [ 'BANGLADESH', ['00',39,400,799,8000,8999,90000,99999]],
-964 => [ 'IRAN', ['00',29,300,549,5500,8999,90000,99999]],
-90 => [ 'NETHERLANDS/BELGIUM', ['00',19,200,499,5000,6999,70000,79999,800000,899999,9000000,9999999]],
-958 => [ 'COLUMBIA', ['0',59,600,899,9000,9499,95000,99999]],
-972 => [ 'PORTUGAL', ['0',1,20,54,550,799,8000,9499,95000,99999]],
-985 => [ 'BELARUS', ['00',39,400,599,6000,8999,90000,99999]],
-9970 => [ 'UGANDA', ['00',39,400,899,9000,9999]],
-983 => [ 'MALAYSIA', ['0',4,50,79,800,899,9000,9899,99000,99999]],
-967 => [ 'MALAYSIA', ['0',5,60,89,900,989,9900,9989,99900,99999]],
-9975 => [ 'MOLDOVA', ['0',4,50,89,900,949,9500,9999]],
-89 => [ 'KOREA', ['00',29,300,699,7000,8499,85000,94999,950000,999999]],
-9960 => [ 'SAUDI ARABIA', ['00',59,600,899,9000,9999]],
-7 => [ 'PEOPLE\'S REP. CHINA', ['00','09',100,499,5000,7999,80000,89999,900000,999999]],
-9961 => [ 'ALGERIA', ['0',4,50,79,800,949,9500,9999]],
-9980 => [ 'PAPUA NEW GUINEA', ['0',3,40,89,900,989,9900,9999]],
-987 => [ 'ARGENTINA', ['00',49,500,899,9000,9499,99000,99999]],
-950 => [ 'ARGENTINA', ['00',49,500,899,9000,9899,99000,99999]],
-99918 => [ 'FAROE ISLANDS', ['0',3,40,89,900,999]],
-969 => [ 'PAKISTAN', ['0',1,20,39,400,799,8000,9999]],
-959 => [ 'CUBA', ['00',19,200,699,7000,8499]],
-9972 => [ 'PERU', ['0',3,40,59,600,899,9000,9999]],
-83 => [ 'POLAND', ['00',91,200,699,7000,8499,85000,89999,900000,999999]],
-82 => [ 'NORWAY', ['00',19,200,699,7000,8999,90000,98999,990000,999999]],
-88 => [ 'ITALY', ['00',19,200,699,7000,8499,85000,89999,900000,999999]],
-81 => [ 'INDIA', ['00',19,200,699,7000,8499,85000,89999,900000,999999]],
-954 => [ 'BULGARIA', ['00',39,400,799,8000,8999,90000,99999]],
-980 => [ 'VENEZUELA', ['00',19,200,599,6000,9999]],
-99909 => [ 'MALTA', ['0',3,40,94,950,999]],
-3 => [ 'GERMANY', ['00',19,200,699,7000,8499,85000,89999,900000,949999,9500000,9899999]],
-955 => [ 'SRI LANKA', ['0',1,20,54,550,899,9000,9499,95000,99999]],
-9987 => [ 'TANZANIA', ['00',39,400,879,8800,9999]],
-9976 => [ 'TANZANIA', ['0',5,60,89,900,989,9990,9999]],
-80 => [ 'CZECHOSLOVAKIA', ['00',19,200,699,7000,8499,85000,89999,900000,999999]],
-99913 => [ 'ANDORRA(NOT USED)', ['0','0']],
-962 => [ 'HONG KONG', ['00',19,200,699,7000,8499]],
-84 => [ 'SPAIN', ['00',19,200,699,7000,8499,9700,9999,85000,89999,95000,96999,900000,949999]],
-976 => [ 'CARICOM', ['0',3,40,59,600,799,8000,9999]],
-963 => [ 'HUNGARY', ['00',19,200,699,7000,8499,85000,89999]],
-99911 => [ 'LESOTHO', ['00',59,600,999]],
-9988 => [ 'GHANA', ['0',2,30,54,550,749,7500,9999]],
-9964 => [ 'GHANA', ['0',6,70,94,950,999]],
-961 => [ 'SLOVENIA', ['00',19,200,599,6000,8999,90000,94999]],
-9984 => [ 'LATVIA', ['00',49,500,899,9000,9999]],
-9978 => [ 'ECUADOR', ['00',94,950,989,9900,9999]],
-86 => [ 'YUGOSLAVIA', ['00',29,300,699,7000,7999,80000,89999,900000,999999]],
-974 => [ 'THAILAND', ['00',19,200,699,7000,8499,85000,89999]],
-9963 => [ 'CYPRUS', ['0',2,30,54,550,749,7500,9999]],
-973 => [ 'ROMANIA', ['0',1,20,54,550,899,9000,9499,95000,99999]],
-99920 => [ 'ANDORRA', ['0',4,50,89,900,999]],
-981 => [ 'SINGAPORE', ['00',19,200,299,3000,9999]],
-9971 => [ 'SINGAPORE', ['0',5,60,89,900,989,9900,9999]],
-977 => [ 'EGYPT', ['00',19,200,499,5000,6999,70000,99999]],
-4 => [ 'JAPAN', ['00',19,200,699,7000,8499,85000,89999,900000,949999,9500000,9999999]],
-99919 => [ 'BENIN', ['0',2,40,69,900,999]],
-92 => [ 'UNESCO', ['0',5,60,79,800,899,9000,9999]],
-9965 => [ 'KAZAKHSTAN', ['00',39,400,899,9000,9999]],
-9981 => [ 'MOROCCO', ['0',1,20,79,800,949,9500,9999]],
-9985 => [ 'ESTONIA', ['0',4,50,79,800,899,9000,9999]],
-99904 => [ 'NETHERLANDS ANTILLES', ['0',4,60,79,900,999]],
-9982 => [ 'ZAMBIA', ['00',30,800,889,9900,9999]],
-2 => [ 'FRANCE/FRENCH', ['00',19,200,399,500,699,7000,8399,84000,89999,900000,949999,9500000,9999999]],
-99915 => [ 'MALDIVES', ['0',4,50,79,800,999]],
-93 => [ 'INDIA (NOT USED)', ['0','0']],
-9977 => [ 'COSTA RICA', ['00',89,900,989,9900,9999]],
-9968 => [ 'COSTA RICA', ['0','0',10,69,700,969,9700,9999]],
-9966 => [ 'KENYA', ['00',69,800,959,9600,9999]],
-99921 => [ 'QATAR', ['0',1,20,69,700,999]],
-979 => [ 'INDONESIA', ['0','0',20,29,400,699,8000,9499,95000,99999]],
-99908 => [ 'MALAWI', ['0','0',10,89,900,999]],
-9973 => [ 'TUNISIA', ['0','0',10,69,700,969,9700,9999]],
-99912 => [ 'BOTSWANA', ['0',5,60,89,900,999]],
-9986 => [ 'LITHUANIA', ['00',39,400,899,9000,9999]]
-);
-
-# i cheat a little bit here.  i know that that the max length is
-# 5, and that i know that those will start with 999xx. :)
-# however, if the data changes i should think about this again.
-$MAX_COUNTRY_CODE_LENGTH = length( 
-	( sort { $a <=> $b } keys %country_data )[-1]
-	);
-}
-
 1;
 
 __END__
@@ -654,7 +544,7 @@ and the major bibliographic data provider in the UK).
 Thanks to Mark W. Eichin E<lt>eichin@thok.orgE<gt> for suggestions and
 discussions on EAN support.
 
-Thanks to Andy Lester E<lt>andy@petdance.orgE<gt> for lots of bug fixes
+Thanks to Andy Lester E<lt>andy@petdance.comE<gt> for lots of bug fixes
 and testing.
 
 =cut
