@@ -1,5 +1,5 @@
-# $Revision: 1.8 $
-# $Id: test.pl,v 1.8 2001/03/27 16:38:12 brian Exp $
+# $Revision: 1.2 $
+# $Id: test.pl,v 1.2 2001/09/05 05:34:43 comdog Exp $
 # Before `make install' is performed this script should be runnable with
 # `make test'. After `make install' it should work as `perl test.pl'
 
@@ -8,7 +8,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $^W = 1; $test = 1; $| = 1; print "1..19\n"; }
+BEGIN { $^W = 1; $test = 1; $| = 1; print "1..20\n"; }
 END {print "not ok 1\n" unless $loaded;}
 use Business::ISBN;
 $loaded = 1;
@@ -30,7 +30,7 @@ my $GOOD_EAN           = "9781565922570";
 my $COUNTRY            = "1";
 my $PUBLISHER          = "56592";
 my $BAD_CHECKSUM_ISBN  = "1565922572";
-my $BAD_COUNTRY_ISBN   = "9990122572";
+my $BAD_COUNTRY_ISBN   = "9990222576";
 my $BAD_PUBLISHER_ISBN = "1456922572";
 my $NULL_ISBN          = undef;
 my $NO_GOOD_CHAR_ISBN  = "abcdefghij";
@@ -95,6 +95,7 @@ print STDERR "is_valid is ", $isbn->is_valid, "\n" if $VERBOSE;
 print STDERR "country is ", $isbn->country_code, "\n" if $VERBOSE;
 print "not " if defined $isbn->country_code;
 print_ok;
+$isbn->fix_checksum;
 }
 
 # bad publisher code?
@@ -159,3 +160,21 @@ print_ok;
 
 }
 
+{
+open FILE, "isbns.txt" or next;
+print STDERR "Checking ISBNs... (this may take a bit)\n";
+
+while( <FILE> )
+	{
+	chomp;
+
+	my $result = Business::ISBN::is_valid_checksum( $_ );
+	$bad++ unless $result eq Business::ISBN::GOOD_ISBN;
+	print STDERR "$_ is not valid? [$result]\n" 
+		unless $result eq Business::ISBN::GOOD_ISBN;	
+	}
+
+close FILE;
+print "not " if $bad;
+print_ok;
+}
